@@ -31,11 +31,14 @@ void
 pygtk_custom_destroy_notify(gpointer user_data)
 {
     PyGtkCustomNotify *cunote = user_data;
+    PyGILState_STATE state;
 
-    pyg_block_threads();
+    g_return_if_fail(user_data);
+    state = pyg_gil_state_ensure();
     Py_XDECREF(cunote->func);
     Py_XDECREF(cunote->data);
-    pyg_unblock_threads();
+    pyg_gil_state_release(state);
+    
     g_free(cunote);
 }
 
