@@ -21,7 +21,7 @@ else:
 common.importModules(buildDir=buildDir,
                      srcDir=srcDir)
 
-SKIP_FILES = ['common', 'runtests']
+SKIP_FILES = ['common', 'runtests', 'testmodule']
 
 dir = os.path.split(os.path.abspath(__file__))[0]
 os.chdir(dir)
@@ -31,7 +31,7 @@ def gettestnames():
     names = map(lambda x: x[:-3], files)
     map(names.remove, SKIP_FILES)
     return names
-        
+
 suite = unittest.TestSuite()
 loader = unittest.TestLoader()
 
